clear_neuromaps_cache: Clear cached neuromaps registry data

View source: R/neuromaps-registry.R

clear_neuromaps_cacheR Documentation

Clear cached neuromaps registry data

Description

Removes the session-level cache of the neuromaps annotation registry, forcing a fresh download on the next call to neuromaps_available() or fetch_neuromaps_annotation().

Usage

clear_neuromaps_cache()

Value

NULL, invisibly.

Examples

clear_neuromaps_cache()

neuromapr documentation built on Feb. 27, 2026, 5:08 p.m.