View source: R/surface-graph.R
| make_surf_graph | R Documentation |
Extracts unique edges from triangular faces, computes Euclidean edge weights, and returns an igraph graph object suitable for geodesic distance computation.
make_surf_graph(vertices, faces)
vertices |
Numeric matrix (n x 3) of vertex coordinates. |
faces |
Integer matrix (m x 3) of face indices (1-indexed). |
An igraph graph object with weighted edges.
Markello RD et al. (2022) Nature Methods 19:1472-1480. doi:10.1038/s41592-022-01625-w
vertices <- matrix(
c(0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 1),
nrow = 4, byrow = TRUE
)
faces <- matrix(c(1L, 2L, 3L, 2L, 3L, 4L), nrow = 2, byrow = TRUE)
g <- make_surf_graph(vertices, faces)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.