| neuromaps_available | R Documentation |
Query the neuromaps registry to see which brain map annotations are available for download. Data is fetched from the neuromaps project's GitHub repository and cached for the session.
neuromaps_available(
source = NULL,
desc = NULL,
space = NULL,
density = NULL,
resolution = NULL,
hemisphere = NULL,
tags = NULL,
format = NULL,
refresh = FALSE,
fixed = FALSE
)
source |
Data source identifier (e.g. |
desc |
Map descriptor key (e.g. |
space |
Coordinate space (e.g. |
density |
Surface vertex density (e.g. |
resolution |
Volume voxel resolution (e.g. |
hemisphere |
Hemisphere ( |
tags |
Character vector of tags. All must match (AND logic). |
format |
Filter by format ( |
refresh |
Logical. If |
fixed |
Logical. If |
All string filter parameters (source, desc, space, density,
resolution, hemisphere, format) are treated as R regular
expressions and matched with grepl(). For example,
source = "^beliveau$" matches exactly, while source = "bel" matches
any source containing "bel". Set fixed = TRUE for literal string
matching. The tags parameter always uses exact matching (AND logic).
When used in fetch_neuromaps_annotation(), source, desc, and space
are exact matches.
A tibble of available annotations with columns: source, desc, space, den, res, hemi, format, fname, full_desc, tags, N, age.
neuromaps_available()
neuromaps_available(source = "beliveau")
neuromaps_available(tags = "pet")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.