| null_baum | R Documentation |
Spin-based null model with maximum-overlap parcel reassignment. After rotating vertex coordinates, each original parcel is assigned the value of the rotated parcel with the most vertex overlap.
null_baum(
data,
coords,
parcellation,
n_perm = 1000L,
seed = NULL,
rotation = c("euler", "rodrigues")
)
data |
Numeric vector of brain map values. |
coords |
List with |
parcellation |
Integer vector of parcel labels for all vertices.
|
n_perm |
Integer number of null permutations to generate. |
seed |
Optional integer seed for reproducibility. |
rotation |
Rotation generation method: |
A null_distribution object.
Baum GL et al. (2020) PNAS 117:21854-21861. doi:10.1073/pnas.2005518117
coords <- list(lh = matrix(rnorm(30), 10, 3), rh = matrix(rnorm(30), 10, 3))
parcellation <- c(rep(1L, 5), rep(2L, 5), rep(3L, 5), rep(4L, 5))
data <- c(1.0, 2.0, 3.0, 4.0)
nd <- null_baum(data, coords, parcellation, n_perm = 10L, seed = 1L)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.