View source: R/nulls-cornblath.R
| null_cornblath | R Documentation |
Spin-based null model where each rotated vertex receives the label of its nearest non-medial-wall original vertex, then parcels are reassigned by majority vote among the resulting vertex labels.
null_cornblath(
data,
coords,
parcellation,
n_perm = 1000L,
seed = NULL,
rotation = c("euler", "rodrigues")
)
data |
Numeric vector of brain map values. |
coords |
List with |
parcellation |
Integer vector of parcel labels for all vertices.
|
n_perm |
Integer number of null permutations to generate. |
seed |
Optional integer seed for reproducibility. |
rotation |
Rotation generation method: |
A null_distribution object.
Cornblath EJ et al. (2020) Communications Biology 3:590. doi:10.1038/s42003-020-01296-5
coords <- list(lh = matrix(rnorm(30), 10, 3), rh = matrix(rnorm(30), 10, 3))
parcellation <- c(rep(1L, 5), rep(2L, 5), rep(3L, 5), rep(4L, 5))
data <- c(1.0, 2.0, 3.0, 4.0)
nd <- null_cornblath(data, coords, parcellation, n_perm = 10L, seed = 1L)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.