| parcellate | R Documentation |
High-level wrapper that reads data and parcellation from file paths or vectors, then aggregates vertices into parcels.
parcellate(data, parcellation, summary_func = mean)
data |
Numeric vector or file path to a GIFTI/NIfTI brain map. |
parcellation |
Integer vector of labels or file path to a GIFTI label file. |
summary_func |
Function to summarise each parcel (default: mean). |
Named numeric vector of parcel-level values.
Markello RD et al. (2022) Nature Methods 19:1472-1480. doi:10.1038/s41592-022-01625-w
data <- c(1.0, 2.0, 3.0, 4.0)
labels <- c(1L, 1L, 2L, 2L)
parcellate(data, labels)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.