read_brain_map_values: Read vertex/voxel values from a brain map file

View source: R/utils.R

read_brain_map_valuesR Documentation

Read vertex/voxel values from a brain map file

Description

Reads GIFTI (.func.gii) or NIfTI (.nii.gz) files and returns the values as a numeric vector. Used internally by compare_maps() when file paths are passed instead of numeric vectors.

Usage

read_brain_map_values(path)

Arguments

path

Path to a .func.gii (GIFTI) or .nii.gz (NIfTI) file.

Value

A numeric vector of map values.

Examples

## Not run: 
read_brain_map_values("cortical_thickness.func.gii")
read_brain_map_values("brain_volume.nii.gz")

## End(Not run)

neuromapr documentation built on Feb. 27, 2026, 5:08 p.m.