Removes the session-level cache of the neuromaps annotation registry,
forcing a fresh download on the next call to neuromaps_available() or
fetch_neuromaps_annotation().
Removes the session-level cache of the neuromaps annotation registry,
forcing a fresh download on the next call to neuromaps_available() or
fetch_neuromaps_annotation().